==> drd-8.x-3.10.tar.gz: drd/modules/drd_pi_acquia/src/Entity/Account.php <==
<?php

namespace Drupal\drd_pi_acquia\Entity;

use Drupal\drd_pi\DrdPiAccount;
use Drupal\drd_pi\DrdPiCore;
use Drupal\drd_pi\DrdPiDomain;
use Drupal\drd_pi\DrdPiHost;
use GuzzleHttp\Client;

/**
 * Defines the acquia Account entity.
 *
 * @ConfigEntityType(
 *   id = "acquia_account",
 *   label = @Translation("Acquia Account"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\drd_pi\DrdPiAccountListBuilder",
 *     "form" = {
 *       "add" = "Drupal\drd_pi_acquia\Entity\AccountForm",
 *       "edit" = "Drupal\drd_pi_acquia\Entity\AccountForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "acquia_account",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/drd/settings/acquia/accounts/{acquia_account}",
 *     "add-form" = "/drd/settings/acquia/accounts/add",
 *     "edit-form" = "/drd/settings/acquia/accounts/{acquia_account}/edit",
 *     "delete-form" = "/drd/settings/acquia/accounts/{acquia_account}/delete",
 *     "collection" = "/drd/settings/acquia/accounts"
 *   }
 * )
 */
class Account extends DrdPiAccount implements AccountInterface {

  /** @var string */
  protected $email;

  /** @var string */
  protected $private_key;

  /**
   * @inheritdoc
   */
  public static function getConfigName() {
    return 'drd_pi_acquia.settings';
  }

  /**
   * @inheritDoc
   */
  public function getPlatformName() {
    return 'Acquia';
  }

  /**
   * @inheritDoc
   */
  public function getEmail() {
    return $this->email;
  }

  /**
   * @inheritDoc
   */
  public function getPrivateKey() {
    return $this->private_key;
  }

  private function getSiteAliasFilename($host_id) {
    return str_replace(':', '.', $host_id) . '.aliases.drushrc.php';
  }

  private function getSiteAlias($host_id, $core_id) {
    return ' @' . str_replace(':', '.', $host_id) . '.' . $core_id;
  }

  /**
   * @inheritDoc
   */
  public function getPlatformHosts() {
    $this->hosts = [];

    if ($result = $this->curl('sites')) {
      foreach ($result as $item) {
        $name = implode(' ', [
          $this->getPlatformName(),
          $this->label(),
          $item,
        ]);
        $this->hosts[$item] = new DrdPiHost($this, $name, $item);
      }
    }

    if ($result = $this->curl('me/drushrc')) {
      foreach ($result as $key => $aliases) {
        file_put_contents(
          'temporary://' . $this->getSiteAliasFilename($key),
          '<?php'. PHP_EOL . '$drush_major_version=8;' . PHP_EOL . implode(PHP_EOL, (array) $aliases)
        );
      }
    }
    return $this->hosts;
  }

  /**
   * @inheritDoc
   */
  public function getPlatformCores($host) {
    $this->cores = [];

    if ($result = $this->curl('sites/' . $host->id() . '/envs')) {
      foreach ($result as $item) {
        $core = new DrdPiCore($this, $item->name, $item->name);
        $core->setHost($host);
        $domain = new DrdPiDomain($this, $item->name, $item->name);
        $domain->setDetails($core, $item->default_domain);
        $core->addDomain($domain);
        $this->cores[$item->name] = $core;
      }
    }
    return $this->cores;
  }

  public function curl($command) {
    $endpoint = $this->config->get('endpoint') . '/' . $command . '.json';
    try {
      $client = new Client([
        'base_uri' => $endpoint,
        'auth' => [
          $this->getEmail(),
          $this->getPrivateKey()
        ],
      ]);
      $response = $client->request('get');
      if ($response->getStatusCode() < 300) {
        return json_decode($response->getBody());
      }
    }
    catch (\Exception $ex) {
      // Ignore
    }
    return [];
  }

  /**
   * @inheritdoc
   */
  public function drush($domain, $drushcmd) {
    $cmd = 'drush --strict=0 --no-interaction --yes --alias-path=' .
      drupal_realpath('temporary://') .
      $this->getSiteAlias($domain->host()->id(), $domain->id()) .
      ' ' . $drushcmd;
    if (empty(parent::shell($cmd))) {
      return TRUE;
    }
    \Drupal::service('drd.logging')->log('critical', $this->lastShellOutput);
    return FALSE;
  }

}

==> drd-8.x-3.11.tar.gz: drd/modules/drd_pi_acquia/src/Entity/Account.php <==
<?php

namespace Drupal\drd_pi_acquia\Entity;

use Drupal\drd_pi\DrdPiAccount;
use Drupal\drd_pi\DrdPiCore;
use Drupal\drd_pi\DrdPiDomain;
use Drupal\drd_pi\DrdPiHost;
use GuzzleHttp\Client;

/**
 * Defines the acquia Account entity.
 *
 * @ConfigEntityType(
 *   id = "acquia_account",
 *   label = @Translation("Acquia Account"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\drd_pi\DrdPiAccountListBuilder",
 *     "form" = {
 *       "add" = "Drupal\drd_pi_acquia\Entity\AccountForm",
 *       "edit" = "Drupal\drd_pi_acquia\Entity\AccountForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "acquia_account",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/drd/settings/acquia/accounts/{acquia_account}",
 *     "add-form" = "/drd/settings/acquia/accounts/add",
 *     "edit-form" = "/drd/settings/acquia/accounts/{acquia_account}/edit",
 *     "delete-form" = "/drd/settings/acquia/accounts/{acquia_account}/delete",
 *     "collection" = "/drd/settings/acquia/accounts"
 *   }
 * )
 */
class Account extends DrdPiAccount implements AccountInterface {

  /**
   * Email address of this account.
   *
   * @var string
   */
  protected $email;

  /**
   * Private key of this account.
   *
   * @var string
   */
  protected $privateKey;

  /**
   * {@inheritdoc}
   */
  public static function getConfigName() {
    return 'drd_pi_acquia.settings';
  }

  /**
   * {@inheritdoc}
   */
  public function getPlatformName() {
    return 'Acquia';
  }

  /**
   * {@inheritdoc}
   */
  public function getEmail() {
    return $this->email;
  }

  /**
   * {@inheritdoc}
   */
  public function getPrivateKey() {
    return $this->privateKey;
  }

  /**
   * Returns the filename for the alias definitions of the given host.
   *
   * @param string $host_id
   *   Host id defined as "string:string".
   *
   * @return string
   *   Filename.
   */
  private function getSiteAliasFilename($host_id) {
    return str_replace(':', '.', $host_id) . '.aliases.drushrc.php';
  }

  /**
   * Returns the the alias of the given core on the given host.
   *
   * @param string $host_id
   *   Host id defined as "string:string".
   * @param string $core_id
   *   Core id as simple string.
   *
   * @return string
   *   Alias.
   */
  private function getSiteAlias($host_id, $core_id) {
    return '@' . str_replace(':', '.', $host_id) . '.' . $core_id;
  }

  /**
   * {@inheritdoc}
   */
  public function getPlatformHosts() {
    $this->hosts = [];

    if ($result = $this->curl('sites')) {
      foreach ($result as $item) {
        $name = implode(' ', [
          $this->getPlatformName(),
          $this->label(),
          $item,
        ]);
        $this->hosts[$item] = new DrdPiHost($this, $name, $item);
      }
    }

    if ($result = $this->curl('me/drushrc')) {
      foreach ($result as $key => $aliases) {
        file_put_contents(
          'temporary://' . $this->getSiteAliasFilename($key),
          '<?php' . PHP_EOL . '$drush_major_version=8;' . PHP_EOL . implode(PHP_EOL, (array) $aliases)
        );
      }
    }
    return $this->hosts;
  }

  /**
   * {@inheritdoc}
   */
  public function getPlatformCores(DrdPiHost $host) {
    $this->cores = [];

    if ($result = $this->curl('sites/' . $host->id() . '/envs')) {
      foreach ($result as $item) {
        $core = new DrdPiCore($this, $item->name, $item->name);
        $core->setHost($host);
        $domain = new DrdPiDomain($this, $item->name, $item->name);
        $domain->setDetails($core, $item->default_domain);
        $core->addDomain($domain);
        $this->cores[$item->name] = $core;
      }
    }
    return $this->cores;
  }

  /**
   * Execute a curl request on the platform.
   *
   * @param string $command
   *   The command for the curl request.
   *
   * @return array
   *   Json decoded response from the platform.
   */
  public function curl($command) {
    $endpoint = $this->config->get('endpoint') . '/' . $command . '.json';
    try {
      $client = new Client([
        'base_uri' => $endpoint,
        'auth' => [
          $this->getEmail(),
          $this->getPrivateKey(),
        ],
      ]);
      $response = $client->request('get');
      if ($response->getStatusCode() < 300) {
        return json_decode($response->getBody());
      }
    }
    catch (\Exception $ex) {
      // Ignore.
    }
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function drush(DrdPiDomain $domain, $drushcmd) {
    $cmd = 'drush --strict=0 --no-interaction --yes --alias-path=' .
      drupal_realpath('temporary://') .
      ' ' . $this->getSiteAlias($domain->host()->id(), $domain->id()) .
      ' ' . $drushcmd;
    if (empty(parent::shell($cmd))) {
      return TRUE;
    }
    \Drupal::service('drd.logging')->log('critical', $this->lastShellOutput);
    return FALSE;
  }

}
